from setuptools import setup

setup(name='gauss_bin_distributions',
      version='1.3',
      description='Gaussian and Binomial distributions',
      packages=['gauss_bin_distributions'],
      author = 'Andrei-Claudiu',
      zip_safe=False)
